smartcard.wx

# ``smartcard`.`wx``

package documentation

wxpython smartcard utility module.

__author__ = "http://www.gemalto.com"

Copyright 2001-2012 gemalto Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com

This file is part of pyscard.

pyscard is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation; either version 2.1 of the License, or (at your option) any later version.

pyscard is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with pyscard; if not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Module | `APDUHexValidator` | A wxValidator that matches APDU in hexadecimal such as:
Module | `APDUTracerPanel` | Graphical APDU Tracer.
Module | `CardAndReaderTreePanel` | wxPython panel display cards/readers as a TreeCtrl.
Module | `ReaderToolbar` | wxPython toolbar with reader icons implementing ReaderObserver.
Module | `SimpleSCardApp` | Simple wxPython wxApp for smartcard.
Module | `SimpleSCardAppEventObserver` | Smartcard event observer.
Module | `SimpleSCardAppFrame` | Simple wxpython frame for smart card application.

From `__init__.py`:

Function | `main_is_frozen` | Undocumented
Constant | `ICO_READER` | Undocumented
Constant | `ICO_SMARTCARD` | Undocumented

def main_is_frozen():

Undocumented

ICO_SMARTCARD =

Undocumented

Value
    os.path.join(os.path.dirname(__file__), 'resources', 'smartcard.ico')

ICO_READER =

Undocumented

Value
    os.path.join(os.path.dirname(__file__), 'resources', 'reader.ico')